# Serene Bach plugin for handling MT flash calendar.
#
# Release 1.00 (September 13,2006)
#         1.01 (September 21,2006) correspond to euc.
#         1.02 (September 26,2006) use sb::Language.
#         1.03 (September 28,2006) add path of calendar.xml.
#
# This software is provided as-is. You may use it for commercial or 
# personal use. If you distribute it, please keep this notice intact.
#
# Copyright (c) 2005-2006 Yujiro Araki

package sb::Plugin::FlashCalendarHandler;

use sb::Plugin();

our $file = 'calendar.xml';

sb::Plugin->register_plugin(
    'lang' => {
        'ja' => 'euc',
        'en' => 'ascii',
    },
    'text' => {
        'type'    => 'cms',
        'name'    => 'FlashCalendarHandler',
        'text'    => 'Handle MT Flash Calendar',
        'author'  => 'Yujiro Araki',
        'detail'  => 'http://www.koikikukan.com/',
        'version' => '1.03',
    },
    'data' => 0,
    'file' => 'flashcalendarhandler.txt',
);

# register callback function to cms entry point
sb::Plugin->register_content_module(
    'type'     => 'main',
    'callback' => \&sb::Content::FlashCalendarHandler::_list_all,
    'field'    => 'flash_calendar',
);

package sb::Content::FlashCalendarHandler;

use sb::Language ();

sub _list_all {
    my $cms = shift;
    my %var = @_;

    return 0 if $var{'mode'} ne 'page';

    my @linklist;
    my $lang = sb::Config->get->value('conf_lang');
    my $charset = $var{'lang'}->charset;
    push(@linklist,qq|<?xml version="1.0" encoding="UTF-8"?>\n<feed version="0.3" xmlns="http://purl.org/atom/ns#" xmlns:dc="http://purl.org/dc/elements/1.1/" xml:lang="$lang">|);

    my @entries = sb::Data->load('Entry','cond'=>{'stat'=>[1]},'sort'=>'date','order'=>1);
    for my $entry (@entries) {
        my $url = $entry->permalink('cat'=>$var{'cat'},
                    'type'=>($var{'mode'} eq 'mob') ? 'Mobile' : $var{'conf'}->value('conf_entry_archive')
        );
        my $date = sb::Time->format(
            'time' => $entry->date,
            'form' => '%Year%-%Mon%-%Day%T%Hour%:%Min%:%Sec%Z',
            'zone' => $var{'conf'}->value('conf_timezone')
        );
        $title = $entry->subj;
        if ($charset eq 'EUC-JP') {
            $title = sb::Language->get->convert($title, 'utf8');
        }
        push(@linklist,qq|<entry>\n<link>$url</link>\n<created>$date</created>\n<title>$title</title>\n</entry>|);
    }
    push(@linklist,qq|</feed>\n|);

    my $body = join("\n",@linklist);
    $file = sb::Config->get->value('conf_dir_base') . $file;
    eval {
        open(TOPOUT,">$file") or die(sb::Language->get->string('error_file_open') . $file);
        binmode(TOPOUT);
        print TOPOUT $body;
        close(TOPOUT);
        chmod(sb::Config->get->value('basic_file_attr'), $file);
    };
    return 0 if($@);
    return 1;
}

1;
__END__
